@@ -42,6 +42,8 @@ def check_config(conf):
         # Use 0.1% of the RAM as a batch size:
         # ~1 billion for big servers, ~10 million for small desktop machines
         conf["batch_size"] = int(psutil.virtual_memory().total / 1000)
+    if "llp_gammas" not in conf:
+        conf["llp_gammas"] = "-0,-1,-2,-3,-4"
     if "max_ram" not in conf:
         conf["max_ram"] = str(psutil.virtual_memory().total)
     if "java_tool_options" not in conf:
